- **I'm submitting a ...**
  - [ ] bug
  - [ ] feature request
  - [ ] support question

### Feature Request / Support Question

<!--If it is a feature request or support question, describe it in detail in this section and delete the sections below.-->

### Bug

<!--If it is a bug, answer the following questions and add information that you think is relevant.-->

1. **What is the current behavior?**

1. **What is the expected behavior? What is the motivation / use case for changing the behavior?**

1. **What are the steps to reproduce this bug? Please provide a minimal working example of the bug if possible.**

1. **Please tell us about your environment:**

1. HELICS version: <!-- 1.3.0 (07-31-18) -->

```sh
$ helics_app --version
2.4.2 (2020-03-28)
```

- Operating System: [all | Windows | Mac | Linux]
- Language Extension: [all | Python | MATLAB | Java]

- **Other information** (e.g. detailed explanation, stacktraces, related issues, suggestions how to fix, links for us to have context, eg. stackoverflow, gitter, etc)
